@@ -5,5 +5,7 @@ rename <- function(x, from, to) {
 resample <- function(x, ...) x[sample.int(length(x), ...)]
 
 sampleWithin <- function(group) {
-  tapply(1:length(group), group, resample, 1)
+  tapply(seq_along(group), group, resample, 1)
 }
+
+.coordsColNames <- c("xcor", "ycor")
